@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _LOG_LEVEL_H_
-#define _LOG_LEVEL_H_
+#ifndef LOG_LEVEL_H
+#define LOG_LEVEL_H
 
 #include <QColor>
 #include <QString>
@@ -35,14 +35,14 @@ public:
 
     virtual ~LogLevel();
 
-    int id();
-    QString name();
+    int id() const;
+    QString name() const;
 
-    QString icon();
+    QString icon() const;
 
-    QColor color();
+    QColor color() const;
 
-    QPixmap pixmap();
+    QPixmap pixmap() const;
 
 private:
     LogLevelPrivate *const d;
