@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _APACHE_ACCESS_ANALYZER_H_
-#define _APACHE_ACCESS_ANALYZER_H_
+#ifndef APACHE_ACCESS_ANALYZER_H
+#define APACHE_ACCESS_ANALYZER_H
 
 #include <KLocalizedString>
 
@@ -42,9 +42,9 @@ public:
     {
     }
 
-    virtual ~ApacheAccessAnalyzer() {}
+    ~ApacheAccessAnalyzer() override {}
 
-    LogViewColumns initColumns() Q_DECL_OVERRIDE
+    LogViewColumns initColumns() override
     {
         LogViewColumns columns;
 
@@ -63,11 +63,11 @@ public:
     }
 
 protected:
-    LogFileReader *createLogFileReader(const LogFile &logFile) Q_DECL_OVERRIDE { return new LocalLogFileReader(logFile); }
+    LogFileReader *createLogFileReader(const LogFile &logFile) override { return new LocalLogFileReader(logFile); }
 
-    Analyzer::LogFileSortMode logFileSortMode() Q_DECL_OVERRIDE { return Analyzer::AscendingSortedLogFile; }
+    Analyzer::LogFileSortMode logFileSortMode() override { return Analyzer::AscendingSortedLogFile; }
 
-    LogLine *parseMessage(const QString &logLine, const LogFile &originalLogFile) Q_DECL_OVERRIDE
+    LogLine *parseMessage(const QString &logLine, const LogFile &originalLogFile) override
     {
         QString line(logLine);
 
@@ -134,4 +134,4 @@ protected:
     }
 };
 
-#endif // _APACHE_ACCESS_ANALYZER_H_
+#endif // _APACHE_ACCESS_ANALYZER_H
