@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _DAEMON_FACTORY_H_
-#define _DAEMON_FACTORY_H_
+#ifndef DAEMON_FACTORY_H
+#define DAEMON_FACTORY_H
 
 #include <QList>
 
@@ -34,9 +34,9 @@ class DaemonLogModeFactory : public LogModeFactory
     Q_OBJECT
 
 public:
-    QList<LogMode *> createLogModes() const Q_DECL_OVERRIDE;
+    QList<LogMode *> createLogModes() const override;
 
-    LogModeAction *createLogModeAction() const Q_DECL_OVERRIDE;
+    LogModeAction *createLogModeAction() const override;
 };
 
-#endif // _DAEMON_FACTORY_H_
+#endif // _DAEMON_FACTORY_H
