@@ -54,7 +54,7 @@ StatusBar::StatusBar(QWidget *parent)
     : QStatusBar(parent)
     , d(new StatusBarPrivate())
 {
-    d->lineCountLabel = new QLabel(QLatin1String(""), this);
+    d->lineCountLabel = new QLabel(this);
     d->lineCountLabel->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
     d->lineCountLabel->setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
     d->lineCountLabel->setLineWidth(2);
@@ -67,7 +67,7 @@ StatusBar::StatusBar(QWidget *parent)
     d->toggleHistory->setFlat(true);
     addPermanentWidget(d->toggleHistory, 0);
 
-    connect(d->toggleHistory, SIGNAL(clicked()), this, SLOT(toggleHistory()));
+    connect(d->toggleHistory, &QPushButton::clicked, this, &StatusBar::toggleHistory);
     */
 
     /*
@@ -79,7 +79,7 @@ StatusBar::StatusBar(QWidget *parent)
     d->messageList = new KComboBox(this);
     d->messageList->setInsertPolicy(QComboBox::InsertAtTop);
     d->messageList->setMaxVisibleItems(5);
-    connect(d->messageList, SIGNAL(currentIndexChanged(int)), this, SLOT(selectLastHistory()));
+    connect(d->messageList, QOverload<int>::of(&KComboBox::currentIndexChanged), this, &StatusBar::selectLastHistory);
     /*
         //TODO Define a specifical palette (and make it works !)
         QPalette palette(d->messageList->palette());
@@ -91,7 +91,7 @@ StatusBar::StatusBar(QWidget *parent)
     */
     addPermanentWidget(d->messageList, 4);
 
-    d->lastModificationLabel = new QLabel(QLatin1String(""), this);
+    d->lastModificationLabel = new QLabel(this);
     d->lastModificationLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
     d->lastModificationLabel->setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
     d->lastModificationLabel->setLineWidth(2);
@@ -115,7 +115,7 @@ void StatusBar::changeLastModification(const QTime &lastModification)
     // d->lastModificationLabel->setText(i18n("Last updated: %1.",
     // KLocale::global()->formatTime(lastModification, true, false) ));
     d->lastModificationLabel->setText(
-        i18n("Last updated: %1.", QLocale().toString(lastModification, QString("hh:mm:ss"))));
+        i18n("Last updated: %1.", QLocale().toString(lastModification, QStringLiteral("hh:mm:ss"))));
 }
 
 void StatusBar::changeMessage(const QString &message)
@@ -124,7 +124,7 @@ void StatusBar::changeMessage(const QString &message)
     // d->messageList->insertItem(0, i18n("%1: %2", KLocale::global()->formatTime(QTime::currentTime(), true,
     // false), message));
     d->messageList->insertItem(
-        0, i18n("%1: %2", QLocale().toString(QTime::currentTime(), QString("hh:mm:ss")), message));
+        0, i18n("%1: %2", QLocale().toString(QTime::currentTime(), QStringLiteral("hh:mm:ss")), message));
 
     // 100 log history message max.
     if (d->messageList->count() > 100) {
